@@ -1,26 +1,25 @@
-import random
-import sys
+import pwd
 import os
-import re
 
-from ooni import geoip
 from ooni.managers import ReportEntryManager, MeasurementManager
 from ooni.reporter import Report
-from ooni.utils import log, pushFilenameStack
+from ooni.utils import log, generate_filename
 from ooni.utils.net import randomFreePort
 from ooni.nettest import NetTest, getNetTestInformation
 from ooni.settings import config
 from ooni import errors
+from ooni.nettest import test_class_name_to_name
 
 from txtorcon import TorConfig, TorState, launch_tor, build_tor_connection
 
 from twisted.internet import defer, reactor
 from twisted.internet.endpoints import TCP4ClientEndpoint
 
+
 class Director(object):
     """
-    Singleton object responsible for coordinating the Measurements Manager and the
-    Reporting Manager.
+    Singleton object responsible for coordinating the Measurements Manager
+    and the Reporting Manager.
 
     How this all looks like is as follows:
 
@@ -59,6 +58,7 @@ class Director(object):
     +------+
 
     """
+
     _scheduledTests = 0
     # Only list NetTests belonging to these categories
     categories = ['blocking', 'manipulation']
@@ -91,13 +91,13 @@ class Director(object):
         # This deferred is fired once all the measurements and their reporting
         # tasks are completed.
         self.allTestsDone = defer.Deferred()
-        self.sniffer = None
+        self.sniffers = {}
 
     def getNetTests(self):
         nettests = {}
+
         def is_nettest(filename):
-            return not filename == '__init__.py' \
-                    and filename.endswith('.py')
+            return not filename == '__init__.py' and filename.endswith('.py')
 
         for category in self.categories:
             dirname = os.path.join(config.nettest_directory, category)
@@ -105,29 +105,46 @@ class Director(object):
             for filename in os.listdir(dirname):
                 if is_nettest(filename):
                     net_test_file = os.path.join(dirname, filename)
-                    nettest = getNetTestInformation(net_test_file)
+                    try:
+                        nettest = getNetTestInformation(net_test_file)
+                    except:
+                        log.err("Error processing %s" % filename)
+                        continue
                     nettest['category'] = category.replace('/', '')
 
                     if nettest['id'] in nettests:
                         log.err("Found a two tests with the same name %s, %s" %
-                                (nettest_path, nettests[nettest['id']]['path']))
+                                (net_test_file,
+                                 nettests[nettest['id']]['path']))
                     else:
-                        category = dirname.replace(config.nettest_directory, '')
+                        category = dirname.replace(config.nettest_directory,
+                                                   '')
                         nettests[nettest['id']] = nettest
 
         return nettests
 
     @defer.inlineCallbacks
-    def start(self, start_tor=False):
+    def start(self, start_tor=False, check_incoherences=True):
         self.netTests = self.getNetTests()
 
-        if config.advanced.start_tor and start_tor:
-            yield self.startTor()
-        elif config.tor.control_port:
-            log.msg("Connecting to Tor Control Port...")
-            yield self.getTorState()
+        if start_tor:
+            if check_incoherences:
+                yield config.check_tor()
+            if config.advanced.start_tor:
+                yield self.startTor()
+            elif config.tor.control_port:
+                log.msg("Connecting to Tor Control Port...")
+                yield self.getTorState()
 
-        yield config.probe_ip.lookup()
+        if config.global_options['no-geoip']:
+            aux = [False]
+            if config.global_options.get('annotations') is not None:
+                annotations = [k.lower() for k in config.global_options['annotations'].keys()]
+                aux = map(lambda x: x in annotations, ["city", "country", "asn"])
+            if not all(aux):
+                log.msg("You should add annotations for the country, city and ASN")
+        else:
+            yield config.probe_ip.lookup()
 
     @property
     def measurementSuccessRatio(self):
@@ -181,14 +198,19 @@ class Director(object):
         self.totalMeasurementRuntime += measurement.runtime
         self.successfulMeasurements += 1
         measurement.result = result
+        test_name = test_class_name_to_name(measurement.testInstance.name)
+        if test_name in self.sniffers:
+            sniffer = self.sniffers[test_name]
+            config.scapyFactory.unRegisterProtocol(sniffer)
+            sniffer.close()
+            del self.sniffers[test_name]
         return measurement
 
     def measurementFailed(self, failure, measurement):
-        log.msg("Failed doing measurement: %s" % measurement)
+        log.debug("Failed doing measurement: %s" % measurement)
         self.totalMeasurementRuntime += measurement.runtime
 
         self.failedMeasurements += 1
-        self.failures.append((failure, measurement))
         measurement.result = failure
         return measurement
 
@@ -210,7 +232,8 @@ class Director(object):
             self.allTestsDone.callback(None)
 
     @defer.inlineCallbacks
-    def startNetTest(self, net_test_loader, reporters):
+    def startNetTest(self, net_test_loader, report_filename,
+                     collector_address=None):
         """
         Create the Report for the NetTest and start the report NetTest.
 
@@ -222,11 +245,10 @@ class Director(object):
             self.allTestsDone = defer.Deferred()
 
         if config.privacy.includepcap:
-            if not config.reports.pcap:
-                config.reports.pcap = config.generate_pcap_filename(net_test_loader.testDetails)
-            self.startSniffing()
+            self.startSniffing(net_test_loader.testDetails)
 
-        report = Report(reporters, self.reportEntryManager)
+        report = Report(net_test_loader.testDetails, report_filename,
+                        self.reportEntryManager, collector_address)
 
         net_test = NetTest(net_test_loader, report)
         net_test.director = self
@@ -243,37 +265,45 @@ class Director(object):
         finally:
             self.netTestDone(net_test)
 
-    def startSniffing(self):
+    def startSniffing(self, testDetails):
         """ Start sniffing with Scapy. Exits if required privileges (root) are not
         available.
         """
-        from ooni.utils.txscapy import ScapyFactory, ScapySniffer
-        config.scapyFactory = ScapyFactory(config.advanced.interface)
+        from ooni.utils.txscapy import ScapySniffer, ScapyFactory
 
-        if os.path.exists(config.reports.pcap):
-            log.msg("Report PCAP already exists with filename %s" % config.reports.pcap)
-            log.msg("Renaming files with such name...")
-            pushFilenameStack(config.reports.pcap)
+        if config.scapyFactory is None:
+            config.scapyFactory = ScapyFactory(config.advanced.interface)
 
-        if self.sniffer:
-            config.scapyFactory.unRegisterProtocol(self.sniffer)
-        self.sniffer = ScapySniffer(config.reports.pcap)
-        config.scapyFactory.registerProtocol(self.sniffer)
-        log.msg("Starting packet capture to: %s" % config.reports.pcap)
+        if not config.reports.pcap:
+            prefix = 'report'
+        else:
+            prefix = config.reports.pcap
+        filename = config.global_options['reportfile'] if 'reportfile' in config.global_options.keys() else None
+        filename_pcap = generate_filename(testDetails, filename=filename, prefix=prefix, extension='pcap')
+        if len(self.sniffers) > 0:
+            pcap_filenames = set(sniffer.pcapwriter.filename for sniffer in self.sniffers.values())
+            pcap_filenames.add(filename_pcap)
+            log.msg("pcap files %s can be messed up because several netTests are being executed in parallel." %
+                    ','.join(pcap_filenames))
+
+        sniffer = ScapySniffer(filename_pcap)
+        self.sniffers[testDetails['test_name']] = sniffer
+        config.scapyFactory.registerProtocol(sniffer)
+        log.msg("Starting packet capture to: %s" % filename_pcap)
 
     @defer.inlineCallbacks
     def getTorState(self):
         connection = TCP4ClientEndpoint(reactor, '127.0.0.1',
-                config.tor.control_port)
+                                        config.tor.control_port)
         config.tor_state = yield build_tor_connection(connection)
 
-
     def startTor(self):
         """ Starts Tor
         Launches a Tor with :param: socks_port :param: control_port
         :param: tor_binary set in ooniprobe.conf
         """
         log.msg("Starting Tor...")
+
         @defer.inlineCallbacks
         def state_complete(state):
             config.tor_state = state
@@ -281,7 +311,7 @@ class Director(object):
             log.debug("We now have the following circuits: ")
             for circuit in state.circuits.values():
                 log.debug(" * %s" % circuit)
-            
+
             socks_port = yield state.protocol.get_conf("SocksPort")
             control_port = yield state.protocol.get_conf("ControlPort")
 
@@ -324,9 +354,10 @@ class Director(object):
         if config.tor.bridges:
             tor_config.UseBridges = 1
             if config.advanced.obfsproxy_binary:
-                tor_config.ClientTransportPlugin = \
-                        'obfs2,obfs3 exec %s managed' % \
-                        config.advanced.obfsproxy_binary
+                tor_config.ClientTransportPlugin = (
+                    'obfs2,obfs3 exec %s managed' %
+                    config.advanced.obfsproxy_binary
+                )
             bridges = []
             with open(config.tor.bridges) as f:
                 for bridge in f:
@@ -336,19 +367,22 @@ class Director(object):
                     else:
                         bridges.append(bridge.strip())
             tor_config.Bridge = bridges
-        
+
         if config.tor.torrc:
             for i in config.tor.torrc.keys():
                 setattr(tor_config, i, config.tor.torrc[i])
 
+        if os.geteuid() == 0:
+            tor_config.User = pwd.getpwuid(os.geteuid()).pw_name
+
         tor_config.save()
 
-        if not hasattr(tor_config,'ControlPort'):
+        if not hasattr(tor_config, 'ControlPort'):
             control_port = int(randomFreePort())
             tor_config.ControlPort = control_port
             config.tor.control_port = control_port
 
-        if not hasattr(tor_config,'SocksPort'):
+        if not hasattr(tor_config, 'SocksPort'):
             socks_port = int(randomFreePort())
             tor_config.SocksPort = socks_port
             config.tor.socks_port = socks_port
