@@ -6,6 +6,7 @@ from twisted.web.error import Error
 from twisted.internet.error import ConnectionRefusedError, TCPTimedOutError
 from twisted.internet.error import DNSLookupError, ConnectError, ConnectionLost
 from twisted.internet.error import TimeoutError as GenericTimeoutError
+from twisted.internet.error import ProcessDone, ConnectionDone
 
 from twisted.python import usage
 
@@ -49,7 +50,8 @@ def handleAllFailures(failure):
         CommandNotSupported,
         ConnectError,
         ConnectionLost,
-        CancelledError)
+        CancelledError, 
+        ConnectionDone)
 
     return failureToString(failure)
 
@@ -144,6 +146,12 @@ def failureToString(failure):
         # log.err("Task timed out")
         string = 'task_timed_out'
 
+    elif isinstance(failure.value, ProcessDone):
+        string = 'process_done'
+
+    elif isinstance(failure.value, ConnectionDone):
+        string = 'connection_done'
+
     else:
         # log.err("Unknown failure type: %s" % type(failure.value))
         string = 'unknown_failure %s' % str(failure.value)
@@ -346,4 +354,4 @@ class ProtocolAlreadyRegistered(Exception):
 
 
 class LibraryNotInstalledError(Exception):
-    pass
\ No newline at end of file
+    pass
