@@ -206,7 +206,7 @@ class ProbeIP(object):
             self.resolveGeodata()
             defer.returnValue(self.address)
         except errors.InsufficientPrivileges:
-            log.debug("Cannot determine the probe IP address with a traceroute, becase of insufficient priviledges")
+            log.debug("Cannot determine the probe IP address with a traceroute, becase of insufficient privileges")
         except:
             log.msg("Unable to lookup the probe IP via traceroute")
 
@@ -215,9 +215,9 @@ class ProbeIP(object):
             log.msg("Found your IP via a GeoIP service: %s" % self.address)
             self.resolveGeodata()
             defer.returnValue(self.address)
-        except Exception, e:
+        except Exception:
             log.msg("Unable to lookup the probe IP via GeoIPService")
-            raise e
+            raise
 
     @defer.inlineCallbacks
     def askGeoIPService(self):
