@@ -10,7 +10,8 @@ from twisted.python import usage, reflect
 
 from ooni import otime
 from ooni.tasks import Measurement
-from ooni.utils import log, checkForRoot, sanitize_options
+from ooni.utils import log, sanitize_options, randomStr
+from ooni.utils.net import hasRawSocketPermission
 from ooni.settings import config
 
 from ooni import errors as e
@@ -131,6 +132,7 @@ class NetTestLoader(object):
     method_prefix = 'test'
     collector = None
     requiresTor = False
+    reportID = None
 
     def __init__(self, options, test_file=None, test_string=None):
         self.onionInputRegex = re.compile(
@@ -202,18 +204,21 @@ class NetTestLoader(object):
             input_file_hashes.append(input_file['hash'])
 
         options = sanitize_options(self.options)
-        test_details = {'start_time': otime.epochToUTC(time.time()),
-                        'probe_asn': config.probe_ip.geodata['asn'],
-                        'probe_cc': config.probe_ip.geodata['countrycode'],
-                        'probe_ip': config.probe_ip.geodata['ip'],
-                        'probe_city': config.probe_ip.geodata['city'],
-                        'test_name': self.testName,
-                        'test_version': self.testVersion,
-                        'software_name': 'ooniprobe',
-                        'software_version': software_version,
-                        'options': options,
-                        'input_hashes': input_file_hashes
-                        }
+        test_details = {
+            'start_time': otime.epochToUTC(time.time()),
+            'probe_asn': config.probe_ip.geodata['asn'],
+            'probe_cc': config.probe_ip.geodata['countrycode'],
+            'probe_ip': config.probe_ip.geodata['ip'],
+            'probe_city': config.probe_ip.geodata['city'],
+            'test_name': self.testName,
+            'test_version': self.testVersion,
+            'software_name': 'ooniprobe',
+            'software_version': software_version,
+            'options': options,
+            'input_hashes': input_file_hashes,
+            'report_id': self.reportID,
+            'test_helpers': self.testHelpers
+        }
         return test_details
 
     def _parseNetTestOptions(self, klass):
@@ -320,6 +325,11 @@ class NetTestLoader(object):
         self.testName = test_class_name_to_name(test_class.name)
         self.testCases = test_cases
         self.testClasses = set([])
+        self.testHelpers = {}
+
+        if config.reports.unique_id is True:
+            self.reportID = randomStr(64)
+
         for test_class, test_method in self.testCases:
             self.testClasses.add(test_class)
 
@@ -339,8 +349,8 @@ class NetTestLoader(object):
                 klass.localOptions = options
 
             test_instance = klass()
-            if test_instance.requiresRoot:
-                checkForRoot()
+            if test_instance.requiresRoot and not hasRawSocketPermission():
+                raise e.InsufficientPrivileges
             if test_instance.requiresTor:
                 self.requiresTor = True
             test_instance.requirements()
@@ -445,13 +455,14 @@ class NetTest(object):
         return ' '.join(tc.name for tc, _ in self.testCases)
 
     def doneNetTest(self, result):
-        if not self.summary:
-            return
-        print "Summary for %s" % self.testDetails['test_name']
-        print "------------" + "-"*len(self.testDetails['test_name'])
-        for test_class in self.testClasses:
-            test_instance = test_class()
-            test_instance.displaySummary(self.summary)
+        if self.summary:
+            print "Summary for %s" % self.testDetails['test_name']
+            print "------------" + "-"*len(self.testDetails['test_name'])
+            for test_class in self.testClasses:
+                test_instance = test_class()
+                test_instance.displaySummary(self.summary)
+        if self.testDetails["report_id"]:
+            print "Report ID: %s" % self.testDetails["report_id"]
 
     def doneReport(self, report_results):
         """
