@@ -1,16 +1,20 @@
 from twisted.python import usage
 from urlparse import urlsplit
-from ooni.templates import dnst,httpt
+
+from ooni.templates import dnst, httpt
+
 
 class UsageOptions(usage.Options):
     optParameters = [
         ['resolver', 'r', '8.8.8.8',
-        'Specify the DNS resolver to use for DNS queries'],
+            'Specify the DNS resolver to use for DNS queries'],
     ]
 
 
-class DNSnHTTP(dnst.DNSTest,httpt.HTTPTest):
-    inputFile = ["filename","f",None,"file containing urls to test for blocking."]
+class DNSnHTTP(dnst.DNSTest, httpt.HTTPTest):
+    inputFile = ["filename", "f", None,
+                 "file containing urls to test for blocking."]
+
     usageOptions = UsageOptions
     name = 'DNS n HTTP'
     version = '0.1'
