@@ -1,12 +1,23 @@
+import os
+
 from ooni.settings import config
 from ooni.utils import unzip, gunzip
 
 from ooni.deckgen.processors import citizenlab_test_lists
 from ooni.deckgen.processors import namebench_dns_servers
 
-config.read_config_file()
+__version__ = "0.1.0"
 
-__version__ = "0.0.1"
+if os.access(config.var_lib_path, os.W_OK):
+    resources_directory = os.path.join(config.var_lib_path,
+                                       "resources")
+    geoip_directory = os.path.join(config.var_lib_path,
+                                   "GeoIP")
+else:
+    resources_directory = os.path.join(config.ooni_home,
+                                       "resources")
+    geoip_directory = os.path.join(config.ooni_home,
+                                   "GeoIP")
 
 inputs = {
     "namebench-dns-servers.csv": {
@@ -18,24 +29,31 @@ inputs = {
     "citizenlab-test-lists.zip": {
         "url": "https://github.com/citizenlab/test-lists/archive/master.zip",
         "action": unzip,
-        "action_args": [config.resources_directory],
+        "action_args": [resources_directory],
         "processor": citizenlab_test_lists
     }
 }
 
 geoip = {
+    "GeoLiteCity.dat.gz": {
+        "url": "https://geolite.maxmind.com/download/"
+               "geoip/database/GeoLiteCity.dat.gz",
+        "action": gunzip,
+        "action_args": [geoip_directory],
+        "processor": None
+    },
     "GeoIPASNum.dat.gz": {
-        "url": "http://www.maxmind.com/download/"
+        "url": "https://geolite.maxmind.com/download/"
                "geoip/database/asnum/GeoIPASNum.dat.gz",
         "action": gunzip,
-        "action_args": [config.advanced.geoip_data_dir],
+        "action_args": [geoip_directory],
         "processor": None
     },
     "GeoIP.dat.gz": {
-        "url": "http://geolite.maxmind.com/"
+        "url": "https://geolite.maxmind.com/"
                "download/geoip/database/GeoLiteCountry/GeoIP.dat.gz",
         "action": gunzip,
-        "action_args": [config.advanced.geoip_data_dir],
+        "action_args": [geoip_directory],
         "processor": None
     }
 }
