@@ -3,8 +3,8 @@ import os
 from twisted.internet import defer
 from twisted.web.client import downloadPage
 
-from ooni.settings import config
-from ooni.resources import inputs, geoip
+from ooni.resources import inputs, geoip, resources_directory
+from ooni.utils import unzip, gunzip
 
 
 @defer.inlineCallbacks
@@ -12,7 +12,11 @@ def download_resource(resources):
     for filename, resource in resources.items():
         print "Downloading %s" % filename
 
-        filename = os.path.join(config.resources_directory, filename)
+        if resource["action"] in [unzip, gunzip] and resource["action_args"]:
+                    dirname = resource["action_args"][0]
+                    filename = os.path.join(dirname, filename)
+        else:
+            filename = os.path.join(resources_directory, filename)
         if not os.path.exists(filename):
             directory = os.path.dirname(filename)
             if not os.path.isdir(directory):
