@@ -1,7 +1,7 @@
 import os
-import sys
 import yaml
 import getpass
+from ConfigParser import SafeConfigParser
 
 from twisted.internet import defer, reactor
 from twisted.internet.endpoints import TCP4ClientEndpoint
@@ -10,7 +10,7 @@ from os.path import abspath, expanduser
 
 from ooni.utils.net import ConnectAndCloseProtocol, connectProtocol
 from ooni import geoip
-from ooni.utils import Storage, log
+from ooni.utils import Storage, log, get_ooni_root
 from ooni import errors
 
 
@@ -32,37 +32,88 @@ class OConfig(object):
         self.privacy = Storage()
         self.set_paths()
 
+    def embedded_settings(self, category, option):
+        embedded_settings = os.path.join(get_ooni_root(), 'settings.ini')
+        if os.path.isfile(embedded_settings):
+            settings = SafeConfigParser()
+            with open(embedded_settings) as fp:
+                settings.readfp(fp)
+            return settings.get(category, option)
+        return None
+
+    @property
+    def var_lib_path(self):
+        var_lib_path = self.embedded_settings("directories", "var_lib")
+        if var_lib_path:
+            return os.path.abspath(var_lib_path)
+        return "/var/lib/ooni"
+
+    @property
+    def usr_share_path(self):
+        usr_share_path = self.embedded_settings("directories", "usr_share")
+        if usr_share_path:
+            return os.path.abspath(usr_share_path)
+        return "/usr/share/ooni"
+
+    @property
+    def data_directory_candidates(self):
+        dirs = [
+            os.path.join(expanduser('~'+self.current_user), '.ooni'),
+            self.var_lib_path,
+            self.usr_share_path,
+            os.path.join(get_ooni_root(), '..', 'data'),
+            '/usr/share/'
+        ]
+        if os.getenv("OONI_DATA_DIR"):
+            dirs.insert(0, os.getenv("OONI_DATA_DIR"))
+        if self.global_options.get('datadir'):
+            dirs.insert(0, abspath(expanduser(self.global_options['datadir'])))
+        return dirs
+
     @property
     def data_directory(self):
-        data_directory = abspath(os.path.join(__file__, '..', '..', 'data'))
+        for target_dir in self.data_directory_candidates:
+            if os.path.isdir(target_dir):
+                return target_dir
+        return self.var_lib_path
 
-        if os.getenv("OONI_DATA_DIR"):
-            data_directory = os.getenv("OONI_DATA_DIR")
-        elif self.global_options.get('datadir'):
-            data_directory = abspath(expanduser(self.global_options['datadir']))
-        elif self.advanced.get('data_dir'):
-            data_directory = self.advanced['data_dir']
-        elif hasattr(sys, 'real_prefix'):
-            data_directory = os.path.abspath(os.path.join(sys.prefix, 'share', 'ooni'))
-        elif not os.path.exists(data_directory):
-            data_directory = '/usr/share/ooni/'
-
-        return data_directory
-
-    def set_paths(self, ooni_home=None):
-        if ooni_home:
-            self._custom_home = ooni_home
-
-        self.nettest_directory = abspath(os.path.join(__file__, '..', 'nettests'))
-
-        self.ooni_home = os.path.join(expanduser('~'+self.current_user), '.ooni')
+    @property
+    def ooni_home(self):
+        home = expanduser('~'+self.current_user)
+        if os.getenv("HOME"):
+            home = os.getenv("HOME")
         if self._custom_home:
-            self.ooni_home = self._custom_home
-        self.inputs_directory = os.path.join(self.ooni_home, 'inputs')
-        self.decks_directory = os.path.join(self.ooni_home, 'decks')
+            return self._custom_home
+        else:
+            return os.path.join(home, '.ooni')
+
+    def get_data_file_path(self, file_name):
+        for target_dir in self.data_directory_candidates:
+            file_path = os.path.join(target_dir, file_name)
+            if os.path.isfile(file_path):
+                return file_path
+
+    def set_paths(self):
+        self.nettest_directory = os.path.join(get_ooni_root(), 'nettests')
+
+        if self.advanced.inputs_dir:
+            self.inputs_directory = self.advanced.inputs_dir
+        else:
+            self.inputs_directory = os.path.join(self.ooni_home, 'inputs')
+
+        if self.advanced.decks_dir:
+            self.decks_directory = self.advanced.decks_dir
+        else:
+            self.decks_directory = os.path.join(self.ooni_home, 'decks')
+
         self.reports_directory = os.path.join(self.ooni_home, 'reports')
-        self.report_log_file = os.path.join(self.ooni_home, 'reporting.yml')
-        self.resources_directory = os.path.join(self.data_directory, "resources")
+        self.resources_directory = os.path.join(self.data_directory,
+                                                "resources")
+        if self.advanced.report_log_file:
+            self.report_log_file = self.advanced.report_log_file
+        else:
+            self.report_log_file = os.path.join(self.ooni_home,
+                                                'reporting.yml')
 
         if self.global_options.get('configfile'):
             config_file = self.global_options['configfile']
@@ -71,16 +122,13 @@ class OConfig(object):
             self.config_file = os.path.join(self.ooni_home, 'ooniprobe.conf')
 
         if 'logfile' in self.basic:
-            self.basic.logfile = expanduser(self.basic.logfile.replace('~','~'+self.current_user))
+            self.basic.logfile = expanduser(self.basic.logfile.replace(
+                '~', '~'+self.current_user))
 
-        if not os.path.exists(self.data_directory):
-            log.err("Data directory %s does not exists" % self.data_directory)
-            log.err("Edit data_dir inside of %s" % self.config_file)
-
-
-    def initialize_ooni_home(self, ooni_home=None):
-        if ooni_home:
-            self.set_paths(ooni_home)
+    def initialize_ooni_home(self, custom_home=None):
+        if custom_home:
+            self._custom_home = custom_home
+            self.set_paths()
 
         if not os.path.isdir(self.ooni_home):
             print "Ooni home directory does not exist."
@@ -88,25 +136,19 @@ class OConfig(object):
             os.mkdir(self.ooni_home)
             os.mkdir(self.inputs_directory)
             os.mkdir(self.decks_directory)
-        if not os.path.isdir(self.reports_directory):
-            os.mkdir(self.reports_directory)
 
     def _create_config_file(self):
         target_config_file = self.config_file
         print "Creating it for you in '%s'." % target_config_file
-        usr_share_path = '/usr/share'
-        if hasattr(sys, 'real_prefix'):
-            usr_share_path = os.path.abspath(os.path.join(sys.prefix, 'share'))
-        sample_config_file = os.path.join(self.data_directory,
-                                          'ooniprobe.conf.sample')
+        sample_config_file = self.get_data_file_path('ooniprobe.conf.sample')
 
         with open(sample_config_file) as f:
             with open(target_config_file, 'w+') as w:
                 for line in f:
-                    if line.startswith('    data_dir: '):
-                        w.write('    data_dir: %s\n' % self.data_directory)
-                    elif line.startswith('    geoip_data_dir: '):
-                        w.write('    geoip_data_dir: %s\n' % os.path.join(usr_share_path, 'GeoIP'))
+                    if line.startswith('    logfile: '):
+                        w.write('    logfile: %s\n' % (
+                            os.path.join(self.ooni_home, 'ooniprobe.log'))
+                        )
                     else:
                         w.write(line)
 
@@ -178,3 +220,7 @@ class OConfig(object):
             self.log_incoherences(incoherent)
 
 config = OConfig()
+if not os.path.isfile(config.config_file) \
+       and os.path.isfile('/etc/ooniprobe.conf'):
+    config.global_options['configfile'] = '/etc/ooniprobe.conf'
+    config.set_paths()
