@@ -7,5 +7,9 @@ class ConfigTestCase(unittest.TestCase):
     def setUp(self):
         config.initialize_ooni_home("ooni_home")
 
+    def skipTest(self, reason):
+        raise unittest.SkipTest(reason)
+
     def tearDown(self):
-        config.read_config_file()
\ No newline at end of file
+        config.set_paths()
+        config.read_config_file()
