@@ -2,9 +2,9 @@ from twisted.python import failure
 from twisted.internet import defer
 
 from ooni.tasks import BaseTask, TaskWithTimeout
-from ooni.nettest import NetTest
 from ooni.managers import TaskManager
 
+
 class MockMeasurementFailOnce(BaseTask):
     def run(self):
         f = open('dummyTaskFailOnce.txt', 'w')
@@ -15,6 +15,7 @@ class MockMeasurementFailOnce(BaseTask):
         else:
             return defer.fail(failure.Failure)
 
+
 class MockMeasurementManager(TaskManager):
     def __init__(self):
         self.successes = []
@@ -26,6 +27,7 @@ class MockMeasurementManager(TaskManager):
     def succeeded(self, result, task):
         self.successes.append((result, task))
 
+
 class MockReporter(object):
     def __init__(self):
         self.created = defer.Deferred()
@@ -39,20 +41,24 @@ class MockReporter(object):
     def finish(self):
         pass
 
+
 class MockFailure(Exception):
     pass
 
-## from test_managers
+# # from test_managers
 mockFailure = failure.Failure(MockFailure('mock'))
 
+
 class MockSuccessTask(BaseTask):
     def run(self):
         return defer.succeed(42)
 
+
 class MockFailTask(BaseTask):
     def run(self):
         return defer.fail(mockFailure)
 
+
 class MockFailOnceTask(BaseTask):
     def run(self):
         if self.failures >= 1:
@@ -60,14 +66,17 @@ class MockFailOnceTask(BaseTask):
         else:
             return defer.fail(mockFailure)
 
+
 class MockSuccessTaskWithTimeout(TaskWithTimeout):
     def run(self):
         return defer.succeed(42)
 
+
 class MockFailTaskThatTimesOut(TaskWithTimeout):
     def run(self):
         return defer.Deferred()
 
+
 class MockTimeoutOnceTask(TaskWithTimeout):
     def run(self):
         if self.failures >= 1:
@@ -75,6 +84,7 @@ class MockTimeoutOnceTask(TaskWithTimeout):
         else:
             return defer.Deferred()
 
+
 class MockFailTaskWithTimeout(TaskWithTimeout):
     def run(self):
         return defer.fail(mockFailure)
@@ -87,6 +97,7 @@ class MockNetTest(object):
     def succeeded(self, measurement):
         self.successes.append(measurement)
 
+
 class MockMeasurement(TaskWithTimeout):
     def __init__(self, net_test):
         TaskWithTimeout.__init__(self)
@@ -95,14 +106,17 @@ class MockMeasurement(TaskWithTimeout):
     def succeeded(self, result):
         return self.netTest.succeeded(42)
 
+
 class MockSuccessMeasurement(MockMeasurement):
     def run(self):
         return defer.succeed(42)
 
+
 class MockFailMeasurement(MockMeasurement):
     def run(self):
         return defer.fail(mockFailure)
 
+
 class MockFailOnceMeasurement(MockMeasurement):
     def run(self):
         if self.failures >= 1:
@@ -110,6 +124,7 @@ class MockFailOnceMeasurement(MockMeasurement):
         else:
             return defer.fail(mockFailure)
 
+
 class MockDirector(object):
     def __init__(self):
         self.successes = []
@@ -120,6 +135,7 @@ class MockDirector(object):
     def measurementSucceeded(self, measurement):
         self.successes.append(measurement)
 
+
 ## from test_reporter.py
 class MockOReporter(object):
     def __init__(self):
@@ -133,17 +149,21 @@ class MockOReporter(object):
 
     def createReport(self):
         from ooni.utils import log
+
         log.debug("Creating report with %s" % self)
         self.created.callback(self)
 
+
 class MockOReporterThatFailsWrite(MockOReporter):
     def writeReportEntry(self, entry):
         raise MockFailure
 
+
 class MockOReporterThatFailsOpen(MockOReporter):
     def createReport(self):
         raise MockFailure
 
+
 class MockOReporterThatFailsWriteOnce(MockOReporter):
     def __init__(self):
         self.failure = 0
@@ -154,7 +174,8 @@ class MockOReporterThatFailsWriteOnce(MockOReporter):
             return defer.succeed(42)
         else:
             self.failure += 1
-            raise MockFailure 
+            raise MockFailure
+
 
 class MockTaskManager(TaskManager):
     def __init__(self):
@@ -167,3 +188,18 @@ class MockTaskManager(TaskManager):
     def succeeded(self, result, task):
         self.successes.append((result, task))
 
+
+class MockOONIBClient(object):
+    def lookupTestHelpers(self, required_test_helpers):
+        ret = {
+            'default': {
+                'address': '127.0.0.1',
+                'collector': 'httpo://thirteenchars1234.onion'
+            }
+        }
+        for required_test_helper in required_test_helpers:
+            ret[required_test_helper] = {
+                'address': '127.0.0.1',
+                'collector': 'httpo://thirteenchars1234.onion'
+            }
+        return defer.succeed(ret)
