@@ -5,6 +5,7 @@ from twisted.trial import unittest
 
 from hashlib import sha256
 from ooni.deck import InputFile, Deck
+from ooni.tests.mocks import MockOONIBClient
 
 net_test_string = """
 from twisted.python import usage
@@ -28,6 +29,7 @@ class DummyTestCase(NetTestCase):
 
 class BaseTestCase(unittest.TestCase):
     def setUp(self):
+        self.filename = ""
         self.cwd = os.getcwd()
         self.dummy_deck_content = """- options:
             collector: null
@@ -43,52 +45,44 @@ class BaseTestCase(unittest.TestCase):
             testdeck: null
 """
 
+
 class TestInputFile(BaseTestCase):
+    def tearDown(self):
+        if self.filename != "":
+            os.remove(self.filename)
+
     def test_file_cached(self):
-        file_hash = sha256(self.dummy_deck_content).hexdigest()
+        self.filename = file_hash = sha256(self.dummy_deck_content).hexdigest()
         input_file = InputFile(file_hash, base_path='.')
         with open(file_hash, 'w+') as f:
             f.write(self.dummy_deck_content)
         assert input_file.fileCached
 
     def test_file_invalid_hash(self):
-        invalid_hash = 'a'*64
+        self.filename = invalid_hash = 'a' * 64
         with open(invalid_hash, 'w+') as f:
-            f.write("b"*100)
+            f.write("b" * 100)
         input_file = InputFile(invalid_hash, base_path='.')
         self.assertRaises(AssertionError, input_file.verify)
 
     def test_save_descriptor(self):
         descriptor = {
-                'name': 'spam',
-                'id': 'spam',
-                'version': 'spam',
-                'author': 'spam',
-                'date': 'spam',
-                'description': 'spam'
+            'name': 'spam',
+            'id': 'spam',
+            'version': 'spam',
+            'author': 'spam',
+            'date': 'spam',
+            'description': 'spam'
         }
-        file_id = 'a'*64
+        file_id = 'a' * 64
+        self.filename = file_id + '.desc'
         input_file = InputFile(file_id, base_path='.')
         input_file.load(descriptor)
         input_file.save()
-        assert os.path.isfile(file_id)
+        assert os.path.isfile(self.filename)
 
         assert input_file.descriptorCached
 
-class MockOONIBClient(object):
-    def lookupTestHelpers(self, required_test_helpers):
-        ret = {
-            'default': {
-                'address': '127.0.0.1',
-                'collector': 'httpo://thirteenchars1234.onion'
-            }
-        }
-        for required_test_helper in required_test_helpers:
-            ret[required_test_helper] = {
-                    'address': '127.0.0.1',
-                    'collector': 'httpo://thirteenchars1234.onion'
-        }
-        return defer.succeed(ret)
 
 class TestDeck(BaseTestCase):
     def setUp(self):
@@ -100,6 +94,12 @@ class TestDeck(BaseTestCase):
         with open(os.path.join(self.cwd, 'dummy_test.py'), 'w+') as f:
             f.write(net_test_string)
 
+    def tearDown(self):
+        os.remove(os.path.join(self.cwd, 'dummy_test.py'))
+        os.remove(self.deck_file)
+        if self.filename != "":
+            os.remove(self.filename)
+
     def test_open_deck(self):
         deck = Deck(decks_directory=".")
         deck.bouncer = "httpo://foo.onion"
@@ -111,15 +111,16 @@ class TestDeck(BaseTestCase):
         deck.bouncer = "httpo://foo.onion"
         deck.loadDeck(self.deck_file)
         deck.load({'name': 'spam',
-            'id': 'spam',
-            'version': 'spam',
-            'author': 'spam',
-            'date': 'spam',
-            'description': 'spam'
-        })
+                   'id': 'spam',
+                   'version': 'spam',
+                   'author': 'spam',
+                   'date': 'spam',
+                   'description': 'spam'
+                   })
         deck.save()
+        self.filename = self.deck_file + ".desc"
         deck.verify()
-    
+
     @defer.inlineCallbacks
     def test_lookuptest_helpers(self):
         deck = Deck(decks_directory=".")
